battle = gamestate.new()

function battle:enter()
	--load enemy
	love.filesystem.load('battle/enemies/'..enemytype..'/init')()
	love.filesystem.load('battle/player/init')()
	local a = 1
	for i, v in ipairs(love.filesystem.enumerate('battle/enemies/'..enemytype)) do
		if v:find('.attack') then
			enemy.attack[a] = v
			a = a + 1
		end
	end
	
	--battle menu
	love.filesystem.load('battle/menu/main.menu')()
	menu_selected = 1
	
	--other stuff
	input_timer = 0
	battle_stage = 'player_turn'
	battle_message = ''
end

function battle:keypressed(key)
	if key == ' ' then
		--battle menu selection
		if battle_stage == 'player_turn' then
			menu_option[menu_selected].f()
			menu_selected = 1
		end
	
		--player defense
		if battle_stage == 'enemy_attack' then
			love.filesystem.load('battle/player/'..current_defense..'.defense')()
		end
	end
	
	--more battle menu operation
	if key == 'left' then
		if menu_selected > 1 then
			menu_selected = menu_selected - 1
		end
	end
	
	if key == 'right' then
		if menu_selected < #menu_option then
			menu_selected = menu_selected + 1
		end
	end
	
	if key == 'up' then
		if menu_selected > 2 then
			menu_selected = menu_selected - 2
		end
	end
	
	if key == 'down' then
		if menu_selected < #menu_option - 1 then
			menu_selected = menu_selected + 2
		end
	end
end

function battle:update(dt)
	--input timer stuff
	if input_timer > 0 and battle_stage == 'player_attack' then
		if love.keyboard.isDown(' ') then --player presses button in time
			input_function()
			input_timer = 0
		elseif input_timer - dt < 0 then
			noinput_function()
			input_timer = 0
		else
			input_timer = input_timer - dt
		end
	end
end

function battle:draw()
	love.graphics.setColor(255, 255, 255, 255)
	
	--draw battle menu
	love.graphics.draw(img_battle_menu, 400, 125, 0, 1, 1, img_battle_menu:getWidth() / 2, img_battle_menu:getHeight() / 2)
	love.graphics.setFont(font_earthbound)
	if battle_stage == 'player_turn' then
		for a = 1, 7, 2 do
			if menu_option[a] then
				love.graphics.print(menu_option[a].name, 150, 50 + (20 * (a - 1)))
				if menu_selected == a then
					love.graphics.draw(img_battle_triangle, 130, 50 + (20 * (a - 1)), 0, 1, 1, img_battle_triangle:getWidth(), 0)
				end
			end
		end
		for a = 2, 8, 2 do
			if menu_option[a] then
				love.graphics.print(menu_option[a].name, 450, 50 + (20 * (a - 2)))
				if menu_selected == a then
					love.graphics.draw(img_battle_triangle, 430, 50 + (20 * (a - 2)), 0, 1, 1, img_battle_triangle:getWidth(), 0)
				end
			end
		end
	else
		love.graphics.printf(battle_message, 150, 50, 550)
	end
	
	--draw enemy
	love.graphics.draw(enemy.image, enemy.x + battle_xshift, enemy.y + battle_yshift, 0, 1, 1, enemy.image:getWidth() / 2, enemy.image:getHeight())
	
	--draw input cue
	if input_timer > 0 then
		love.graphics.setColor(0, 0, 0, 100)
		love.graphics.rectangle('fill', 0, 0, 800, 600)
		love.graphics.setColor(255, 255, 255, 255)
		love.graphics.draw(img_input_cue, 400, 500, 0, 1, 1, img_input_cue:getWidth()/2, img_input_cue:getHeight()/2)
	end
	
	--draw player
	love.graphics.draw(player.image, player.x + battle_xshift, player.y + battle_yshift, 0, 1, 1, player.image:getWidth() / 2, player.image:getHeight())
	
	--draw damage messages
	if damage_message then
		love.graphics.setFont(font_damage)
		love.graphics.setColor(damage_message.r, damage_message.g, damage_message.b, damage_message.alpha)
		love.graphics.print(damage_message.text, damage_message.x + battle_xshift, damage_message.y + battle_yshift, 0, damage_message.scale, damage_message.scale)
	end
end

--miscellaneous functions
function player_damage(health)
	player.health = player.health - health
	damage_message = {x = player.x, y = player.y, text = tostring(health), scale = 3, alpha = 255, r = 255, g = 0, b = 0}
	tween(0.05, damage_message, {scale = 1})
	timer.add(0.5, function()
		tween(0.5, damage_message, {scale = 0.3, alpha = 0})
	end)
	battle_message = 'You take '..health..' points of damage!'
end

function enemy_damage(health)
	enemy.health = enemy.health - health
	damage_message = {x = enemy.x, y = player.y, text = tostring(health), scale = 3, alpha = 255, r = 150, g = 150, b = 255}
	tween(0.05, damage_message, {scale = 1})
	timer.add(0.5, function()
		tween(0.5, damage_message, {scale = 0.3, alpha = 0})
	end)
	battle_message = 'The '..enemytype..' takes '..health..' points of damage!'
end

function attack_end()
	if battle_stage == 'player_attack' then
		battle_stage = 'enemy_attack'
		love.filesystem.load('battle/enemies/'..enemytype..'/'..math.random(#enemy.attack)..'.attack')()
	elseif battle_stage == 'enemy_attack' then
		battle_stage = 'player_turn'
		battle_menu = {level = 'main', selected = 1}
	end
	battle_message = ''
end